@@ -22,6 +22,9 @@ JavaScript/TypeScript:
 Python:
 `pip install cdk-github`
 
+C#
+See https://www.nuget.org/packages/CdkGithub
+
 # 📚 Constructs
 
 This library provides the following constructs:
@@ -40,7 +43,7 @@ All (typescript) examples can be found in the folder [examples](src/examples/).
 
 ## ActionSecret
 
-```python
+```typescript
 import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
 import { ActionSecret } from 'cdk-github';
 
@@ -64,7 +67,7 @@ export class ActionSecretStack extends Stack {
 
 ## ActionEnvironmentSecret
 
-```python
+```typescript
 import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
 import { ActionEnvironmentSecret } from 'cdk-github';
 
